"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
class SimpleReportsConfigBuilder {
    constructor(parent) {
        this.properties = {
            parent,
            configuration: this._defaultConfiguration()
        };
    }
    /**
     * The configuration group name
     */
    get _subConfigurationGroupName() {
        return 'reports';
    }
    /**
     * Clear the configuration
     */
    clear() {
        this.properties.configuration = this._defaultConfiguration();
        return this;
    }
    /**
     * Set the root directory
     * @param [value] The new value. Set undefined to set put the default value
     */
    rootDirectoryPath(value) {
        if (_.isNil(value)) {
            this.properties.configuration.rootDirectoryPath = this._defaultConfiguration().rootDirectoryPath;
        }
        else if (_.isString(value)) {
            this.properties.configuration.rootDirectoryPath = value;
        }
        return this;
    }
    /**
     * Returns the parent builder
     */
    parentBuilder() {
        return this.properties.parent;
    }
    /**
     * Generate the object configuration
     */
    build() {
        const userConfig = {
            rootDirectoryPath: this.properties.configuration.rootDirectoryPath
        };
        return _.merge({}, userConfig);
    }
    /**
     * Returns the default configuration
     */
    _defaultConfiguration() {
        return {
            rootDirectoryPath: undefined
        };
    }
}
exports.SimpleReportsConfigBuilder = SimpleReportsConfigBuilder;
//# sourceMappingURL=reports-config-builder.js.map