import { SimpleCoverageConfigBuilder } from './coverage-config-builder';
import { SimpleProjectConfigBuilder } from './project-config-builder';
import { SimpleReportsConfigBuilder } from './reports-config-builder';
import { SimpleTestConfigBuilder } from './test-config-builder';
import { testLauncher } from "../test-launcher";
export declare namespace simpleTestLauncherConfigBuilder {
    interface Properties {
        configuration: Configuration;
        projectConfigBuilder?: SimpleProjectConfigBuilder;
        testConfigBuilder?: SimpleTestConfigBuilder;
        reportsConfigBuilder?: SimpleReportsConfigBuilder;
        coverageConfigBuilder?: SimpleCoverageConfigBuilder;
    }
    interface Configuration {
        steps: Steps;
    }
    interface Steps {
        preLaunch: Step[];
        preTestLaunch: Step[];
        postExecution: Step[];
        cleanUp: Step[];
    }
    interface Step {
        handler: Function;
    }
}
/**
 * The configuration builder
 * In case you need to add a sub configuration builder, end you property name by ConfigBuilder, and it will
 * automatically added in the clear and build function.
 * To be handled by the build function, the builder need to have the property _subConfigurationGroupName defined
 */
export declare class SimpleTestLauncherConfigBuilder {
    /**
     * The properties
     */
    protected properties: simpleTestLauncherConfigBuilder.Properties;
    constructor();
    /**
     * Returns the test configuration
     */
    testConfiguration(): SimpleTestConfigBuilder;
    /**
     * Returns the reports configuration
     */
    reportsConfiguration(): SimpleReportsConfigBuilder;
    /**
     * Returns the coverage configuration
     */
    coverageConfiguration(): SimpleCoverageConfigBuilder;
    /**
     * Returns the project configuration
     */
    projectConfiguration(): SimpleProjectConfigBuilder;
    /**
     * Clear the configuration
     */
    clear(): SimpleTestLauncherConfigBuilder;
    /**
     * Add a pre launch step function
     * @param value The step function to add
     */
    withPreLaunchStep(value: Function): SimpleTestLauncherConfigBuilder;
    /**
     * Add a pre test step function
     * @param value The step function to add
     */
    withPreTestLaunchStep(value: Function): SimpleTestLauncherConfigBuilder;
    /**
     * Add a post execution step function
     * @param value The step function to add
     */
    withPostExecutionStep(value: Function): SimpleTestLauncherConfigBuilder;
    /**
     * Add a clean up step function
     * @param value The step function to add
     */
    withCleanUpStep(value: Function): SimpleTestLauncherConfigBuilder;
    /**
     * Generate the configuration
     */
    build(): testLauncher.configuration.Configuration;
    protected _defaultConfiguration(): simpleTestLauncherConfigBuilder.Configuration;
    /**
     * Create the configuration builders
     */
    protected _createSubConfigurationBuilders(): void;
}
