/// <reference types="node" />
import { Logger } from "./logger";
import { EventEmitter } from "events";
import { jasmineRunner, JasmineRunner } from './jasmine-runner';
export declare namespace simpleJasmineRunner {
    interface LastExecution {
        success: boolean;
    }
    interface Properties {
        instance: object | undefined;
        lastExecution: LastExecution;
        specFileFilters?: Array<string | jasmineRunner.TestSpecFileFilter | RegExp>;
        projectDirectoryPath?: string;
        specDirPath?: string;
        reportDirectoryPath?: string;
        features?: jasmineRunner.ConfigurationFeatures;
    }
    interface FilterTestSpecFilesOptions {
        filePaths: string[];
    }
    interface FilterTestSpecFilesOnResolve {
        filePaths: string[];
    }
    interface GenerateConfigurationOnResolve {
        configuration: object;
    }
    interface CreateReportersOnResolve {
        reporters: object[];
    }
}
/**
 * Jasmine runner
 */
export declare class SimpleJasmineRunner extends EventEmitter implements JasmineRunner {
    protected logger: Logger;
    protected properties: simpleJasmineRunner.Properties;
    constructor();
    readonly lastExecutionSucceed: boolean;
    /**
     * Initialize the runner
     * @param configuration The runner configuration
     */
    initialize(configuration: jasmineRunner.Configuration): Promise<void>;
    /**
     * Start the jasmine execution
     */
    start(options: jasmineRunner.StartOptions): Promise<void>;
    run(options: jasmineRunner.StartOptions): Promise<jasmineRunner.events.Finished>;
    /**
     * Generate the jasmine configuration
     */
    protected generateConfiguration(): Promise<simpleJasmineRunner.GenerateConfigurationOnResolve>;
    /**
     * Filters the spec files with user custom filters
     * @param options Options
     */
    protected filterTestSpecFiles(options: simpleJasmineRunner.FilterTestSpecFilesOptions): Promise<simpleJasmineRunner.FilterTestSpecFilesOnResolve>;
    /**
     * Create the jasmine reports
     */
    protected createReporters(): Promise<simpleJasmineRunner.CreateReportersOnResolve>;
    /**
     * Create and initialize the jasmine instance
     */
    protected createAndInitInstance(): Promise<void>;
    /**
     * Executed when jasmin finished
     */
    protected onJasmineFinished(): void;
}
